@@ -1,32 +1,34 @@
 import uuid
 import xml.etree.ElementTree as ET
+from queue import Empty, Queue
 
 import pytest
 
-from . import assert_xml_diff
-
-from queue import Queue, Empty
-
-from pypsrp.complex_objects import ComplexObject, GenericComplexObject, \
-    ListMeta, ObjectMeta, StackMeta
-from pypsrp.exceptions import SerializationError
-from pypsrp.serializer import Serializer
 from pypsrp._utils import to_string, to_unicode
+from pypsrp.complex_objects import (
+    ComplexObject,
+    GenericComplexObject,
+    ListMeta,
+    ObjectMeta,
+    StackMeta,
+)
+from pypsrp.exceptions import SerializationError
+from pypsrp.serializer import Serializer, TaggedValue
+
+from . import assert_xml_diff
 
 
 class TestSerializer(object):
-
-    @pytest.mark.parametrize('input_val, expected', [
-        ["0123456789abcdefghijklmnopqrstuvwxyz_",
-         "0123456789abcdefghijklmnopqrstuvwxyz_"],
-        ["actual_x000A_string\nnewline",
-         "actual_x005F_x000A_string_x000A_newline"],
-        ["treble clef %s" % b"\xd8\x34\xdd\x1e".decode('utf-16-be'),
-         "treble clef _xD834__xDD1E_"],
-        [None, None],
-        ["upper_X000a_string\nnewline",
-         "upper_x005F_X000a_string_x000A_newline"],
-    ])
+    @pytest.mark.parametrize(
+        "input_val, expected",
+        [
+            ["0123456789abcdefghijklmnopqrstuvwxyz_", "0123456789abcdefghijklmnopqrstuvwxyz_"],
+            ["actual_x000A_string\nnewline", "actual_x005F_x000A_string_x000A_newline"],
+            ["treble clef %s" % b"\xd8\x34\xdd\x1e".decode("utf-16-be"), "treble clef _xD834__xDD1E_"],
+            [None, None],
+            ["upper_X000a_string\nnewline", "upper_x005F_X000a_string_x000A_newline"],
+        ],
+    )
     def test_serialize_string(self, input_val, expected):
         serializer = Serializer()
 
@@ -35,16 +37,19 @@ class TestSerializer(object):
         actual_deserial = serializer._deserialize_string(actual_serial)
         assert actual_deserial == (input_val or "")
 
-    @pytest.mark.parametrize('data, expected', [
-        [u"a", "<S>a</S>"],
-        ["a", "<S>a</S>"],
-        [1, "<I32>1</I32>"],
-        [True, "<B>true</B>"],
-        [False, "<B>false</B>"],
-        [10.0323, "<Sg>10.0323</Sg>"],
-        [uuid.UUID(bytes=b"\x00" * 16),
-         "<G>00000000-0000-0000-0000-000000000000</G>"]
-    ])
+    @pytest.mark.parametrize(
+        "data, expected",
+        [
+            ["a", "<S>a</S>"],
+            ["a", "<S>a</S>"],
+            [1, "<I32>1</I32>"],
+            [True, "<B>true</B>"],
+            [False, "<B>false</B>"],
+            [10.0323, "<Sg>10.0323</Sg>"],
+            [uuid.UUID(bytes=b"\x00" * 16), "<G>00000000-0000-0000-0000-000000000000</G>"],
+            [TaggedValue("U32", 1), "<U32>1</U32>"],
+        ],
+    )
     def test_serialize_primitives(self, data, expected):
         serializer = Serializer()
 
@@ -54,6 +59,8 @@ class TestSerializer(object):
         assert actual_xml == expected_xml
 
         deserial_actual = serializer.deserialize(actual)
+        if isinstance(data, TaggedValue):
+            data = data.value
         assert deserial_actual == data
 
     def test_serialize_byte_string_py3(self):
@@ -70,10 +77,11 @@ class TestSerializer(object):
         data.put("0")
         data.put("1")
         data.put("2")
-        expected = \
-            '<Obj RefId="0"><TN RefId="0"><T>System.Collections.Queue</T>' \
-            '<T>System.Object</T></TN>' \
-            '<QUE><S>0</S><S>1</S><S>2</S></QUE></Obj>'
+        expected = (
+            '<Obj RefId="0"><TN RefId="0"><T>System.Collections.Queue</T>'
+            "<T>System.Object</T></TN>"
+            "<QUE><S>0</S><S>1</S><S>2</S></QUE></Obj>"
+        )
         actual = serializer.serialize(data)
         actual_xml = to_string(ET.tostring(actual))
         assert actual_xml == expected
@@ -95,21 +103,18 @@ class TestSerializer(object):
         data.append("0")
         data.append("1")
         data.append("2")
-        expected = \
-            '<Obj RefId="0"><TN RefId="0"><T>System.Collections.Stack</T>' \
-            '<T>System.Object</T></TN>' \
-            '<STK><S>2</S><S>1</S><S>0</S></STK></Obj>'
+        expected = (
+            '<Obj RefId="0"><TN RefId="0"><T>System.Collections.Stack</T>'
+            "<T>System.Object</T></TN>"
+            "<STK><S>2</S><S>1</S><S>0</S></STK></Obj>"
+        )
 
         actual = serializer.serialize(data, StackMeta())
         actual_xml = to_string(ET.tostring(actual))
         assert actual_xml == expected
 
         deserial_actual = serializer.deserialize(actual)
-        assert deserial_actual == [
-            "2",
-            "1",
-            "0"
-        ]
+        assert deserial_actual == ["2", "1", "0"]
 
     def test_serialize_list(self):
         serializer = Serializer()
@@ -117,21 +122,18 @@ class TestSerializer(object):
         data.append("0")
         data.append("1")
         data.append("2")
-        expected = \
-            '<Obj RefId="0"><TN RefId="0"><T>System.Object[]</T>' \
-            '<T>System.Array</T><T>System.Object</T></TN>' \
-            '<LST><S>0</S><S>1</S><S>2</S></LST></Obj>'
+        expected = (
+            '<Obj RefId="0"><TN RefId="0"><T>System.Object[]</T>'
+            "<T>System.Array</T><T>System.Object</T></TN>"
+            "<LST><S>0</S><S>1</S><S>2</S></LST></Obj>"
+        )
 
         actual = serializer.serialize(data)
         actual_xml = to_string(ET.tostring(actual))
         assert actual_xml == expected
 
         deserial_actual = serializer.deserialize(actual)
-        assert deserial_actual == [
-            "0",
-            "1",
-            "2"
-        ]
+        assert deserial_actual == ["0", "1", "2"]
 
     def test_serialize_list_as_ie(self):
         serializer = Serializer()
@@ -139,10 +141,11 @@ class TestSerializer(object):
         data.append("0")
         data.append("1")
         data.append("2")
-        expected = \
-            '<Obj RefId="0"><TN RefId="0"><T>System.Object[]</T>' \
-            '<T>System.Array</T><T>System.Object</T></TN>' \
-            '<IE><S>0</S><S>1</S><S>2</S></IE></Obj>'
+        expected = (
+            '<Obj RefId="0"><TN RefId="0"><T>System.Object[]</T>'
+            "<T>System.Array</T><T>System.Object</T></TN>"
+            "<IE><S>0</S><S>1</S><S>2</S></IE></Obj>"
+        )
 
         actual = serializer.serialize(data, ListMeta("IE"))
         actual_xml = to_string(ET.tostring(actual))
@@ -152,8 +155,7 @@ class TestSerializer(object):
         serializer = Serializer()
         with pytest.raises(SerializationError) as err:
             serializer._serialize_secure_string("")
-        assert str(err.value) == \
-            "Cannot generate secure string as cipher is not initialised"
+        assert str(err.value) == "Cannot generate secure string as cipher is not initialised"
 
     def test_deserialize_secure_string_no_cipher(self):
         serializer = Serializer()
@@ -165,25 +167,25 @@ class TestSerializer(object):
         serializer = Serializer()
         expected = '<Obj RefId="0"><MS><S N="key">value</S></MS></Obj>'
         obj = GenericComplexObject()
-        obj.extended_properties['key'] = "value"
+        obj.extended_properties["key"] = "value"
         actual = serializer.serialize(obj)
         actual_xml = to_string(ET.tostring(actual))
         assert actual_xml == expected
 
     def test_serialize_dynamic_complex(self):
         serializer = Serializer()
-        expected = \
-            '<Obj RefId="0"><TN RefId="0">' \
-            '<T>System.Management.Automation.PSCustomObject</T>' \
-            '<T>System.Object</T></TN><ToString>to string value</ToString>' \
-            '<I32>1</I32><S>2</S><MS><S N="extended_key">extended</S></MS>' \
+        expected = (
+            '<Obj RefId="0"><TN RefId="0">'
+            "<T>System.Management.Automation.PSCustomObject</T>"
+            "<T>System.Object</T></TN><ToString>to string value</ToString>"
+            '<I32>1</I32><S>2</S><MS><S N="extended_key">extended</S></MS>'
             '<Props><S N="adapted_key">adapted</S></Props></Obj>'
+        )
 
         obj = GenericComplexObject()
-        obj.types = ["System.Management.Automation.PSCustomObject",
-                     "System.Object"]
-        obj.extended_properties['extended_key'] = 'extended'
-        obj.adapted_properties['adapted_key'] = 'adapted'
+        obj.types = ["System.Management.Automation.PSCustomObject", "System.Object"]
+        obj.extended_properties["extended_key"] = "extended"
+        obj.adapted_properties["adapted_key"] = "adapted"
         obj.property_sets = [1, "2"]
         obj.to_string = "to string value"
 
@@ -206,74 +208,61 @@ class TestSerializer(object):
         class SerialObject(ComplexObject):
             def __init__(self, **kwargs):
                 super(SerialObject, self).__init__()
-                self._types = [
-                    "System.Test",
-                    "System.Object"
-                ]
-                self._extended_properties = (
-                    ('man_prop', ObjectMeta("S", optional=False)),
-                )
-                self.man_prop = kwargs.get('man_prop')
+                self._types = ["System.Test", "System.Object"]
+                self._extended_properties = (("man_prop", ObjectMeta("S", optional=False)),)
+                self.man_prop = kwargs.get("man_prop")
 
         serializer = Serializer()
-        xml = '<Obj RefId="0"><TN RefId="0"><T>System.Test</T>' \
-              '<T>System.Object</T></TN><MS /></Obj>'
+        xml = '<Obj RefId="0"><TN RefId="0"><T>System.Test</T>' "<T>System.Object</T></TN><MS /></Obj>"
         with pytest.raises(SerializationError) as err:
             serializer.deserialize(xml, ObjectMeta("Obj", object=SerialObject))
-        assert str(err.value) == \
-            "Mandatory return value for 'Unknown' was not found on object " \
-            "Unknown"
+        assert str(err.value) == "Mandatory return value for 'Unknown' was not found on object Unknown"
 
     def test_deserialize_obj_missing_prop_names(self):
         class SerialObject(ComplexObject):
             def __init__(self, **kwargs):
                 super(SerialObject, self).__init__()
-                self._types = [
-                    "System.Test",
-                    "System.Object"
-                ]
-                self._extended_properties = (
-                    ('man_prop', ObjectMeta("S", name="key", optional=False)),
-                )
-                self.man_prop = kwargs.get('man_prop')
+                self._types = ["System.Test", "System.Object"]
+                self._extended_properties = (("man_prop", ObjectMeta("S", name="key", optional=False)),)
+                self.man_prop = kwargs.get("man_prop")
 
         serializer = Serializer()
-        xml = '<Obj RefId="0"><TN RefId="0"><T>System.Test</T>' \
-              '<T>System.Object</T></TN><ToString>obj</ToString><MS /></Obj>'
+        xml = (
+            '<Obj RefId="0"><TN RefId="0"><T>System.Test</T>'
+            "<T>System.Object</T></TN><ToString>obj</ToString><MS /></Obj>"
+        )
         with pytest.raises(SerializationError) as err:
             serializer.deserialize(xml, ObjectMeta("Obj", object=SerialObject))
-        assert str(err.value) == \
-            "Mandatory return value for 'key' was not found on object obj"
+        assert str(err.value) == "Mandatory return value for 'key' was not found on object obj"
 
     def test_deserialize_dynamic_obj_type_ref(self):
         serializer = Serializer()
-        xml1 = \
-            '<Obj RefId="0"><TN RefId="0">' \
-            '<T>System.Management.Automation.PSCustomObject</T>' \
-            '<T>System.Object</T></TN><ToString>to string value</ToString>' \
-            '<I32>1</I32><S>2</S><MS><S N="extended_key">extended</S></MS>' \
+        xml1 = (
+            '<Obj RefId="0"><TN RefId="0">'
+            "<T>System.Management.Automation.PSCustomObject</T>"
+            "<T>System.Object</T></TN><ToString>to string value</ToString>"
+            '<I32>1</I32><S>2</S><MS><S N="extended_key">extended</S></MS>'
             '<Props><S N="adapted_key">adapted</S></Props></Obj>'
-        xml2 = \
-            '<Obj RefId="2"><TNRef RefId="0" />' \
-            '<ToString>to string value 2</ToString>' \
-            '<I32>1</I32><S>2</S><MS><S N="extended_key">extended</S></MS>' \
+        )
+        xml2 = (
+            '<Obj RefId="2"><TNRef RefId="0" />'
+            "<ToString>to string value 2</ToString>"
+            '<I32>1</I32><S>2</S><MS><S N="extended_key">extended</S></MS>'
             '<Props><S N="adapted_key">adapted</S></Props></Obj>'
+        )
         serializer.deserialize(xml1)
         actual = serializer.deserialize(xml2, clear=False)
         assert str(actual) == "to string value 2"
-        assert actual.types == [
-            "System.Management.Automation.PSCustomObject",
-            "System.Object"
-        ]
+        assert actual.types == ["System.Management.Automation.PSCustomObject", "System.Object"]
 
     def test_deserialize_empty_string(self):
         serializer = Serializer()
-        actual = serializer.deserialize('')
-        assert actual == ''
+        actual = serializer.deserialize("")
+        assert actual == ""
 
     def test_deserialize_unknown_tag(self):
         serializer = Serializer()
-        xml = '''<Obj N="Value" RefId="14">
+        xml = """<Obj N="Value" RefId="14">
     <MS>
         <S N="T">System.Management.Automation.Host.Size</S>
         <Obj N="V" RefId="15">
@@ -283,10 +272,8 @@ class TestSerializer(object):
             </MS>
         </Obj>
     </MS>
-</Obj>'''
-        actual = serializer.deserialize(xml, ObjectMeta(
-            "fake", object=GenericComplexObject
-        ))
+</Obj>"""
+        actual = serializer.deserialize(xml, ObjectMeta("fake", object=GenericComplexObject))
         assert actual == xml
 
     def test_serialize_circualr_reference(self):
@@ -295,7 +282,7 @@ class TestSerializer(object):
         obj.types = [
             "Microsoft.Exchange.Data.Directory.ADObjectId",
             "Microsoft.Exchange.Data.ObjectId",
-            "System.Object"
+            "System.Object",
         ]
         obj.to_string = "com"
         obj.adapted_properties = {
@@ -307,28 +294,29 @@ class TestSerializer(object):
             "IsRelativeDn": False,
             "DomainId": obj,
             "Name": "com",
-            "SecurityIdentifierString": None
+            "SecurityIdentifierString": None,
         }
         obj.property_sets.append("abc")
         obj.property_sets.append(obj)
 
-        expected = \
-            '<Obj RefId="0"><TN RefId="0"><T>Microsoft.Exchange.Data.' \
-            'Directory.ADObjectId</T><T>Microsoft.Exchange.Data.ObjectId</T>' \
-            '<T>System.Object</T></TN><ToString>com</ToString><S>abc</S>' \
-            '<Ref RefId="0" /><Props><I32 N="Depth">0</I32>' \
-            '<S N="DistinguishedName">DC=com</S>' \
-            '<Ref N="DomainId" RefId="0" /><B N="IsDeleted">false</B>' \
-            '<B N="IsRelativeDn">false</B><S N="Name">com</S>' \
-            '<Nil N="OrgHierarchyToIgnore" /><Nil N="Parent" />' \
+        expected = (
+            '<Obj RefId="0"><TN RefId="0"><T>Microsoft.Exchange.Data.'
+            "Directory.ADObjectId</T><T>Microsoft.Exchange.Data.ObjectId</T>"
+            "<T>System.Object</T></TN><ToString>com</ToString><S>abc</S>"
+            '<Ref RefId="0" /><Props><I32 N="Depth">0</I32>'
+            '<S N="DistinguishedName">DC=com</S>'
+            '<Ref N="DomainId" RefId="0" /><B N="IsDeleted">false</B>'
+            '<B N="IsRelativeDn">false</B><S N="Name">com</S>'
+            '<Nil N="OrgHierarchyToIgnore" /><Nil N="Parent" />'
             '<Nil N="SecurityIdentifierString" /></Props></Obj>'
+        )
         actual = serializer.serialize(obj)
         actual_xml = to_string(ET.tostring(actual))
         assert_xml_diff(actual_xml, expected)
 
     def test_deserialize_circular_reference(self):
         serializer = Serializer()
-        xml = '''<Obj N="DomainId" RefId="44">
+        xml = """<Obj N="DomainId" RefId="44">
     <TN RefId="6">
         <T>Microsoft.Exchange.Data.Directory.ADObjectId</T>
         <T>Microsoft.Exchange.Data.ObjectId</T>
@@ -346,12 +334,12 @@ class TestSerializer(object):
         <S N="Name">com</S>
         <Nil N="SecurityIdentifierString"/>
     </Props>
-</Obj>'''
+</Obj>"""
         actual = serializer.deserialize(xml)
         assert str(actual) == "com"
         assert str(actual.adapted_properties["DomainId"]) == "com"
         assert actual.adapted_properties["DomainId"].types == [
             "Microsoft.Exchange.Data.Directory.ADObjectId",
             "Microsoft.Exchange.Data.ObjectId",
-            "System.Object"
+            "System.Object",
         ]
